@@ -6,7 +6,7 @@ from equinox.custom_types import Array
 
 class DropPath(eqx.Module):
     """Effectively dropping a sample from the call.
-    Often used inside a network along side a residual connection."""
+    Often used inside a network along side a residual connection"""
 
     p: float
     inference: bool
@@ -14,9 +14,9 @@ class DropPath(eqx.Module):
     def __init__(self, p: float = 0.0, inference: bool = False):
         """**Arguments:**
 
-        - `p`: The probability to drop a sample entirely during forward pass.
-        - `inference`: Defaults to `False`. If `True`, then the input is returned unchanged.
-        This may be toggled with `equinox.tree_inference`.
+        - `p`: The probability to drop a sample entirely during forward pass
+        - `inference`: Defaults to `False`. If `True`, then the input is returned unchanged
+        This may be toggled with `equinox.tree_inference`
         """
         self.p = p
         self.inference = inference
@@ -24,7 +24,7 @@ class DropPath(eqx.Module):
     def __call__(self, x, *, key: "jax.random.PRNGKey") -> Array:
         """**Arguments:**
 
-        - `x`: An any-dimensional JAX array to drop.
+        - `x`: An any-dimensional JAX array to drop
         - `key`: A `jax.random.PRNGKey` used to provide randomness for calculating
             which elements to dropout. (Keyword only argument.)
         """
