@@ -1,5 +1,18 @@
 from .classification.alexnet import AlexNet, alexnet
+from .classification.densenet import (
+    DenseNet,
+    densenet121,
+    densenet161,
+    densenet169,
+    densenet201,
+)
 from .classification.googlenet import GoogLeNet, googlenet
+from .classification.mobilenetv2 import mobilenet_v2, MobileNetV2
+from .classification.mobilenetv3 import (
+    mobilenet_v3_large,
+    mobilenet_v3_small,
+    MobileNetV3,
+)
 from .classification.resnet import (
     ResNet,
     resnet18,
